<?php

namespace Drupal\cloud_cluster_worker\Plugin\QueueWorker;

use Drupal\cloud_cluster_worker\Service\SyncResourcesService;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Queue\QueueWorkerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Processes for Cloud Cluster Worker Sync Resources Queue.
 *
 * @QueueWorker(
 *   id = "cloud_cluster_worker_sync_resources_queue",
 *   title = @Translation("Cloud Cluster Worker Sync Resources Queue"),
 *   cron = {"time" = 60}
 * )
 */
class CloudClusterWorkerSyncResourcesQueueWorker extends QueueWorkerBase implements ContainerFactoryPluginInterface {

  /**
   * The resources synchronization service.
   *
   * @var \Drupal\cloud_cluster_worker\Service\SyncResourcesService
   */
  protected $syncResources;

  /**
   * Constructs a new LocaleTranslation object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param array $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\cloud_cluster_worker\Service\SyncResourcesService $sync_resources
   *   The resources synchronization service.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    array $plugin_definition,
    SyncResourcesService $sync_resources
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->syncResources = $sync_resources;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('cloud_cluster_worker.sync_resources')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data): void {
    $this->syncResources->send($data['cloud_context'], $data['entity_type'], $data['resource_jsons']);
  }

}
