Feature: Login, logout and list resources on the clean state
  In order to list resources on the clean state
  As a user
  I need to have both Drupal and AWS IAM permissions

  Scenario: Log in with the "Anonymous user" role
    Given I am not logged in
    When I visit "/clouds"
    Then I should be on "/user/login"
    And I should see the heading "Log in"

  @api
  Scenario Outline: Log in
    Given I am logged in as a user with the <role> role
    And I should not see the link "All" in the "nav_bar"
    When I go to "/clouds"
    Then I should get a <code> HTTP response
    And I should see the heading <heading>

    Examples:
      |  role                | code | heading                      |
      | "Authenticated user" | 403  | "Access denied"              |
      | "Administrator"      | 200  | "Add cloud service provider" |

  @api
  Scenario: Log in as an "Administrator"
    Given I am logged in as a user with the "Administrator" role
    And I should not see the link "All" in the "nav_bar"
    When I visit "/clouds"
    Then I should be on "/admin/structure/cloud_config/add"
    And I should see "There is no cloud service provider."
    And I should see the link "AWS Cloud"

  @api
  Scenario Outline: Log out
    Given I am logged in as a user with the <role> role
    And I should not see the link "All" in the "nav_bar"
    And I visit "/"
    And I see the heading "Cloud Service Provider Location Map"
    When I click "Log out"
    Then I should be on "/user/login"
    And I should see the link "Log in"

    Examples:
      | role                 |
      | "Authenticated user" |
      | "Administrator"      |

  @api
  Scenario Outline: View the list of Cloud service providers
    Given I am logged in as a user with the <role> role
    And I should not see the link "All" in the "nav_bar"
    When I go to "/clouds"
    Then I should be on "/admin/structure/cloud_config/add"
    And I should get a <code> HTTP response
    And I should see the heading <heading>

  Examples:
    | role                 | code | heading                      |
    | "Authenticated user" | 403  | "Access denied"              |
    | "Administrator"      | 200  | "Add cloud service provider" |

  @api
  Scenario: "Administrator" can view the list of Cloud service providers
    Given I am logged in as a user with the "Administrator" role
    And I should not see the link "All" in the "nav_bar"
    When I visit "/clouds"
    Then I should be on "/admin/structure/cloud_config/add"
    And I should see "There is no cloud service provider."
    And I should see the link "AWS Cloud"
    And I should see the link "K8s"
    And I should see the link "VMware"

  @api
  Scenario Outline: View the list of AWS resources
    Given I am logged in as a user with the <role> role
    And I should not see the link "All" in the "nav_bar"
    When I go to "/clouds/aws_cloud/instance"
    Then I should get a 200 HTTP response
    And I should see the heading "All AWS Cloud Instances"
    And I should see the button "Apply"
    And I should see the link "Instances"

    Examples:
      | role                 |
      | "Authenticated user" |
      | "Administrator"      |
